{% extends "generic/generic_content.html" %}
{% load crispy_forms_tags %}
{% load i18n %}

{% block title %}
  {% if object %}
    {% blocktrans with object as object %}Edit {{ object }}{% endblocktrans %}
  {% else %}
    {% translate "Create" %}
  {% endif %}
{% endblock title %}

{% block col %}
  <div class="card">
    <div class="card-header">

      {% block card-header-content %}
        {% if object %}
          {% blocktrans with object as object %}Edit {{ object }}{% endblocktrans %}
        {% else %}
          {% translate "Create" %}
        {% endif %}
      {% endblock card-header-content %}

    </div>
    <div class="card-body">{% crispy form form.helper %}</div>
  </div>
{% endblock col %}
