{% if record.forward %}
  {{ record.name }}
  {% if record.obj %}
    <a href="{{ record.obj.get_absolute_url }}">{{ record.obj }}</a>
  {% else %}
    None
  {% endif %}
{% else %}
  {{ record.reverse_name }}
  {% if record.subj %}
    <a href="{{ record.subj.get_absolute_url }}">{{ record.subj }}</a>
  {% else %}
    None
  {% endif %}
{% endif %}
