# Generated by Django 5.2.4 on 2025-08-05 09:27

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("apis_metainfo", "0016_remove_rootobject_self_contenttype"),
    ]

    operations = [
        migrations.SeparateDatabaseAndState(
            state_operations=[
                migrations.DeleteModel(
                    name="Uri",
                ),
            ],
            database_operations=[
                migrations.AlterModelTable(
                    name="Uri",
                    table="uris_uri",
                ),
            ],
        )
    ]
