<div class="row">
  <div class="col">{% include widget.subwidgets.0.template_name with widget=widget.subwidgets.0 %}</div>
  <div class="col-auto">{% include widget.subwidgets.1.template_name with widget=widget.subwidgets.1 %}</div>
</div>
