# Generated by Django 4.2.10 on 2024-04-11 09:26

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("apis_metainfo", "0012_remove_rootobject_deprecated_name"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Collection",
        ),
    ]
