# Generated by Django 5.1.4 on 2025-02-19 17:43

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("apis_metainfo", "0015_uri_content_type_uri_object_id"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="rootobject",
            name="self_contenttype",
        ),
    ]
