# Generated by Django 4.1.10 on 2023-09-13 12:17

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("apis_entities", "0002_remove_tempentityclass_text"),
        ("apis_metainfo", "0005_delete_uricandidate"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Text",
        ),
    ]
