{% extends "generic/generic_content.html" %}
{% load crispy_forms_tags %}
{% load i18n %}

{% block title %}
  {% translate "Import" %}
{% endblock title %}

{% block col %}
  <div class="card">
    <div class="card-header">{% translate "Import" %}</div>
    <div class="card-body">{% crispy form form.helper %}</div>
  </div>
{% endblock col %}
