# Generated by Django 5.1.7 on 2025-04-16 10:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("relations", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="relation",
            name="obj_object_id",
            field=models.PositiveIntegerField(null=True),
        ),
        migrations.AlterField(
            model_name="relation",
            name="subj_object_id",
            field=models.PositiveIntegerField(null=True),
        ),
    ]
