{% load i18n %}

{% block base-nav %}
  {% if object.get_change_permission in perms %}
    <ul class="nav nav-tabs card-header-tabs float-start">

      {% block base-nav-inner %}
        <li class="nav-item">
          <a class="nav-link object-view {% if request.path == object.get_absolute_url %}active{% endif %} "
             href="{{ object.get_absolute_url }}"><span class="material-symbols-outlined material-symbols-align">visibility</span>{% translate "View" %}</a>
        </li>
        <li class="nav-item">
          <a class="nav-link object-edit {% if request.path == object.get_edit_url %}active{% endif %} "
             href="{{ object.get_edit_url }}"><span class="material-symbols-outlined material-symbols-align">edit</span>{% translate "Edit" %}</a>
        </li>
      {% endblock base-nav-inner %}

    </ul>
  {% endif %}
{% endblock base-nav %}
