/* object actions */
.object-view {
    color: var(--object-view-color, rgb(25, 135, 84)) !important;
}

.object-edit {
    color: var(--object-edit-color, rgb(255, 193, 7)) !important;
}

.object-delete {
    color: var(--object-delete-color, rgb(220, 53, 69)) !important;
}

.object-duplicate {
    color: var(--object-duplicate-color, blueviolet);
}

.object-merge {
    color: var(--object-merge-color, dodgerblue);
}

.object-history {
    color: var(--object-history-color, #007bff);
}

.filter-input-selected {
    color: var(--filter-input-selected-color, #228b22);
    font-weight: bold;
}

.mytoast {
    position: fixed;
    bottom: 30px;
    z-index: 1;
    animation: fadein 0.5s, fadeout 0.5s 2.6s;
}

@keyframes fadein {
    from {
        bottom: 0;
        opacity: 0;
    }

    to {
        bottom: 30px;
        opacity: 1;
    }
}

@keyframes fadeout {
    from {
        bottom: 30px;
        opacity: 1;
    }

    to {
        bottom: 0;
        opacity: 0;
    }
}
