{% extends basetemplate|default:"base.html" %}
{% load crispy_forms_tags %}
{% load i18n %}

{% block content %}
  <div class="container">
    <div class="mt-4">
      <form method="post" action="{% url 'apis_core:login' %}">
        {% csrf_token %}
        {{ form|crispy }}
        <input type="submit" value="{% translate "login" %}">
        <input type="hidden" name="next" value="{{ next }}">
      </form>
    </div>
  </div>
{% endblock content %}
